%
% This script file is used to format the output for the LASS tool (see "lass.m").
%
function formatfig(figtype,fighand,par,j1,j2,varargin);

%
%
%
% PARAMETER VALUES:
%
%
%
% FONT SIZE

 fsize = 11;

%
% LEGENDs COORDIMATES (the coordinates of the legends in Steps 1,2,3 and 6
%

leg1 = [0.13,0.02,0.02,0.02];
leg2 = [0.43,0.02,0.02,0.02];
leg3 = [0.73,0.02,0.02,0.02];

%
%
% BEGIN FORMATTING
% 
%

figure(fighand);
set(fighand,'NumberTitle','off');

switch num2str(figtype)

%
% 
% FORMATTING STEP 1:
%
%
case '1'
%
%
%
%
    set(fighand,'FileName','step1fig');
    set(fighand,'Name',' Step 1: Visualization of the local wavelet specta.');
    

figure(fighand);
subplot(2,1,1);
set(gca,'FontSize',fsize);
title(['The local estimates of H(r). Scales: (j_1, j_2) = (', ...
             num2str(j1),',',num2str(j2),'), w = ',num2str(par.window)]);
ylabel('H(r)');
xlabel('Window number');

subplot(2,1,2);
set(gca,'FontSize',fsize);
title('Changes in local wavelet spectra.  Deviations from linearity.');
ylabel('Scales j');
%xlabel('Window number');


figure(fighand);
axes('position',leg1);
colormap(par.cmap);
imagesc(-1,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);

text(1.4,1,' -slope below avg','FontSize',fsize);

axes('position',leg2);

colormap(par.cmap);
imagesc(0,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);
text(1.4,1,' -slope about avg','FontSize',fsize);

axes('position',leg3);

colormap(par.cmap);
imagesc(1,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);
text(1.4,1,' -slope above avg','FontSize',fsize);

%
%
% FORMATTING STEP 2:
%
%
case '2'
         set(fighand,'FileName','step2fig');
         set(fighand,'Name',' Step 2: Visualization of the local wavelet specta.');
     


figure(fighand);
subplot(2,1,1);
set(gca,'FontSize',fsize);
title(['The local estimates of H(r). Scales: (j_1, j_2) = (', ...
             num2str(j1),',',num2str(j2),'), w = ',num2str(par.window)]);
ylabel('H(r)');
xlabel('Window number');

subplot(2,1,2);
set(gca,'FontSize',fsize);
title('Changes in local wavelet spectra.  Deviations from linearity.');
ylabel('Scales j');
%xlabel('Window number');




%
% same as in step 1
%



figure(fighand);
axes('position',leg1);
colormap(par.cmap);
imagesc(-1,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);

text(1.4,1,' -slope below avg','FontSize',fsize);

axes('position',leg2);

colormap(par.cmap);
imagesc(0,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);
text(1.4,1,' -slope about avg','FontSize',fsize);

axes('position',leg3);

colormap(par.cmap);
imagesc(1,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);
text(1.4,1,' -slope above avg','FontSize',fsize);

%
%
% FORMATTING STEP 3
%
%

case {'3'}
         set(fighand,'FileName','step3fig');
         set(fighand,'Name','Step 3: Summary of the local Hurst estimates');
figure(fighand);
subplot(2,1,1);
		       set(gca,'FontSize',fsize);
		       title('Estimated local H(k)');
		       xlabel('Window');
		       axis tight;
		       a = axis;
		       axis([a(1:2), 0.45, 1.05]);

subplot(2,2,3);
		       axis tight;
                       set(gca,'FontSize',fsize);
		       title('Local mean of the data');
		       xlabel('Window number');

subplot(2,2,4);
		       axis tight;
		       set(gca,'FontSize',fsize);
		       title('Local standard deviation');
		       xlabel('Window number');



%
%
% FORMATTING STEP 4
%
%


case {'4'}

         set(fighand,'FileName','step4fig');
         set(fighand,'Name','Step 4: Influence of the window size');

      figure(fighand);
      subplot(2,1,2);
      set(gca,'FontSize',fsize);

      xlabel('time');
      ylabel('Estimated H(t)');
      if par.overlay,
        title(['Estimates of H(t) for different window sizes (j_1 = ', num2str(j1),')']);
      else
        title(['Average of the H(t) estimates over the window sizes (j_1 = ', num2str(j1),')']);
      end;
      subplot(2,1,1);
      set(gca,'FontSize',fsize);
      colorbar('vert');
      
 ylabel('Window Label');
 title(['A Map of H(t) for different window sizes']);
 xlabel('time');

%
%
% FORMATTING STEP 5
%
%

case {'5'}
         set(fighand,'FileName','step5fig');
         set(fighand,'Name','Step 5: Deviations from stationarity');
	 figure(fighand);
	 subplot(2,1,2);
set(gca,'FontSize',fsize);

title('Confidence intervals for mean of H(t) per window.');
xlabel('Window Label');
ylabel('H');

     	subplot(2,1,1);
        set(gca,'FontSize',fsize);
        title(' Cross-time variablity of H(t)');
        xlabel('time');
	ylabel('Window Label'); 


figure(fighand);
axes('position',leg1);
colormap(par.cmap);
imagesc(-1,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);

text(1.4,1,' - H(t) below avg','FontSize',fsize);

axes('position',leg2);

colormap(par.cmap);
imagesc(0,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);
text(1.4,1,' - H(t) about avg','FontSize',fsize);

axes('position',leg3);

colormap(par.cmap);
imagesc(1,[-1,1]);
set(gca,'XTick',[]);
set(gca,'YTick',[]);
text(1.4,1,' - H(t) above avg','FontSize',fsize);

end;
