%  Author: Stilian Stoev <sstoev@math.bu.edu>
%
%  This function is a part of the LASS tool (see also lass.m).  It
%  computes a robust estimate of the log2-mean of the sample x and
%  an estimate of the std of this estimate.  
%
% INPUT:
%  x    <- a vector
%
% OUTPUT:
%  mu   <- a robust estimate of the log2(Mean(x))
%  sd   <- an estimate of the STD of the estimate mu.
%
% USAGE:
%  [mu,sd] = robms(x);
%
function [mu,sd] = robms(x);

iter = 1000;
tresh = 10000;

% An estimate of the median of the distribution of Z^2, Z~N(0,1).
medZ2 = 0.455102;
% An estimate of the ratio b/w the standard deviation of 
% log2(median(Z1^2,...,Zn^2)) and log2(mean(Z1^2,...,Zn^2)) for *large n*.
stdRatio = 1.667033;

nx = length(x);
mu = median(x);

if nx<=tresh,
 z = randn(length(x),iter).^2;
 z = median(z);
 mz = mean(log2(z));
 sz = std(log2(z));
 
 mu = log2(mu) - mz+log2(medZ2);
 sd = sz;
else
 mu = log2(mu);
 sd = (sqrt(2)/(log(2)*(nx)^0.5))*stdRatio;
end;
